@@ -19,18 +19,15 @@
     Home: https://github.com/gorhill/uBlock
 */
 
-'use strict';
+import * as sfp from './static-filtering-parser.js';
 
-/******************************************************************************/
-
-import µb from './background.js';
 import { broadcast } from './broadcast.js';
 import cacheStorage from './cachestorage.js';
-import { ubolog } from './console.js';
 import { i18n$ } from './i18n.js';
 import logger from './logger.js';
-import * as sfp from './static-filtering-parser.js';
-import { orphanizeString, } from './text-utils.js';
+import { orphanizeString } from './text-utils.js';
+import { ubolog } from './console.js';
+import µb from './background.js';
 
 /******************************************************************************/
 
@@ -50,6 +47,9 @@ let remoteServerFriendly = false;
 
 /******************************************************************************/
 
+const hasOwnProperty = (o, p) =>
+    Object.prototype.hasOwnProperty.call(o, p);
+
 const stringIsNotEmpty = s => typeof s === 'string' && s !== '';
 
 const parseExpires = s => {
@@ -107,8 +107,8 @@ const resourceTimeFromXhr = xhr => {
 
 const resourceTimeFromParts = (parts, time) => {
     const goodParts = parts.filter(part => typeof part === 'object');
-    return goodParts.reduce((acc, part) =>
-        ((part.resourceTime || 0) > acc ? part.resourceTime : acc),
+    return goodParts.reduce(
+        (acc, part) => ((part.resourceTime || 0) > acc ? part.resourceTime : acc),
         time
     );
 };
@@ -246,6 +246,7 @@ const fireNotification = function(topic, details) {
 assets.fetch = function(url, options = {}) {
     return new Promise((resolve, reject) => {
     // Start of executor
+    /* eslint-disable indent */
 
     const timeoutAfter = µb.hiddenSettings.assetFetchTimeout || 30;
     const xhr = new XMLHttpRequest();
@@ -318,10 +319,11 @@ assets.fetch = function(url, options = {}) {
         xhr.responseType = options.responseType || 'text';
         xhr.send();
         timeoutTimer.on({ sec: timeoutAfter });
-    } catch (e) {
+    } catch {
         onErrorEvent.call(xhr);
     }
 
+    /* eslint-enable indent */
     // End of executor
     });
 };
@@ -394,7 +396,7 @@ assets.fetchFilterList = async function(mainlistURL) {
     const toParsedURL = url => {
         try {
             return new URL(url.trim());
-        } catch (ex) {
+        } catch {
         }
     };
 
@@ -528,12 +530,12 @@ function getAssetSourceRegistry() {
         assetSourceRegistryPromise = cacheStorage.get(
             'assetSourceRegistry'
         ).then(bin => {
-            if (
-                bin instanceof Object &&
-                bin.assetSourceRegistry instanceof Object
-            ) {
-                assetSourceRegistry = bin.assetSourceRegistry;
-                return assetSourceRegistry;
+            if ( bin instanceof Object ) {
+                if ( bin.assetSourceRegistry instanceof Object ) {
+                    assetSourceRegistry = bin.assetSourceRegistry;
+                    ubolog('Loaded assetSourceRegistry');
+                    return assetSourceRegistry;
+                }
             }
             return assets.fetchText(
                 µb.assetsBootstrapLocation || µb.assetsJsonPath
@@ -543,6 +545,7 @@ function getAssetSourceRegistry() {
                     : assets.fetchText(µb.assetsJsonPath);
             }).then(details => {
                 updateAssetSourceRegistry(details.content, true);
+                ubolog('Loaded assetSourceRegistry');
                 return assetSourceRegistry;
             });
         });
@@ -619,7 +622,7 @@ function updateAssetSourceRegistry(json, silent = false) {
             Array.from(Object.entries(newDict))
                 .filter(a => a[1].content === 'filters' && a[1].off === undefined)
                 .map(a => a[0]);
-    } catch (ex) {
+    } catch {
     }
     if ( newDict instanceof Object === false ) { return; }
 
@@ -673,49 +676,36 @@ let assetCacheRegistryPromise;
 let assetCacheRegistry = {};
 
 function getAssetCacheRegistry() {
-    if ( assetCacheRegistryPromise === undefined ) {
-        assetCacheRegistryPromise = cacheStorage.get(
-            'assetCacheRegistry'
-        ).then(bin => {
-            if (
-                bin instanceof Object &&
-                bin.assetCacheRegistry instanceof Object
-            ) {
-                if ( Object.keys(assetCacheRegistry).length === 0 ) {
-                    assetCacheRegistry = bin.assetCacheRegistry;
-                } else {
-                    console.error(
-                        'getAssetCacheRegistry(): assetCacheRegistry reassigned!'
-                    );
-                    if (
-                        Object.keys(bin.assetCacheRegistry).sort().join() !==
-                        Object.keys(assetCacheRegistry).sort().join()
-                    ) {
-                        console.error(
-                            'getAssetCacheRegistry(): assetCacheRegistry changes overwritten!'
-                        );
-                    }
-                }
-            }
-            return assetCacheRegistry;
-        });
+    if ( assetCacheRegistryPromise !== undefined ) {
+        return assetCacheRegistryPromise;
     }
-
+    assetCacheRegistryPromise = cacheStorage.get(
+        'assetCacheRegistry'
+    ).then(bin => {
+        if ( bin instanceof Object === false ) { return; }
+        if ( bin.assetCacheRegistry instanceof Object === false ) { return; }
+        if ( Object.keys(assetCacheRegistry).length !== 0 ) {
+            return console.error('getAssetCacheRegistry(): assetCacheRegistry reassigned!');
+        }
+        ubolog('Loaded assetCacheRegistry');
+        assetCacheRegistry = bin.assetCacheRegistry;
+    }).then(( ) =>
+        assetCacheRegistry
+    );
     return assetCacheRegistryPromise;
 }
 
 const saveAssetCacheRegistry = (( ) => {
-    const save = function() {
+    const save = ( ) => {
         timer.off();
-        cacheStorage.set({ assetCacheRegistry });
+        return cacheStorage.set({ assetCacheRegistry });
     };
     const timer = vAPI.defer.create(save);
-    return function(lazily) {
-        if ( lazily ) {
-            timer.offon({ sec: 30 });
-        } else {
-            save();
+    return (throttle = 0) => {
+        if ( throttle === 0 ) {
+            return save();
         }
+        timer.offon({ sec: throttle });
     };
 })();
 
@@ -726,7 +716,9 @@ async function assetCacheRead(assetKey, updateReadTime = false) {
     const reportBack = function(content) {
         if ( content instanceof Blob ) { content = ''; }
         const details = { assetKey, content };
-        if ( content === '' ) { details.error = 'ENOTFOUND'; }
+        if ( content === '' || content === undefined ) {
+            details.error = 'ENOTFOUND';
+        }
         return details;
     };
 
@@ -742,55 +734,39 @@ async function assetCacheRead(assetKey, updateReadTime = false) {
         ) + ' ms';
     }
 
-    if (
-        bin instanceof Object === false ||
-        bin.hasOwnProperty(internalKey) === false
-    ) {
-        return reportBack('');
-    }
+    if ( bin instanceof Object === false ) { return reportBack(''); }
+    if ( hasOwnProperty(bin, internalKey) === false ) { return reportBack(''); }
 
     const entry = assetCacheRegistry[assetKey];
-    if ( entry === undefined ) {
-        return reportBack('');
-    }
+    if ( entry === undefined ) { return reportBack(''); }
 
     entry.readTime = Date.now();
     if ( updateReadTime ) {
-        saveAssetCacheRegistry(true);
+        saveAssetCacheRegistry(23);
     }
 
     return reportBack(bin[internalKey]);
 }
 
-async function assetCacheWrite(assetKey, details) {
-    let content = '';
-    let options = {};
-    if ( typeof details === 'string' ) {
-        content = details;
-    } else if ( details instanceof Object ) {
-        content = details.content || '';
-        options = details;
-    }
-
-    if ( content === '' ) {
+async function assetCacheWrite(assetKey, content, options = {}) {
+    if ( content === '' || content === undefined ) {
         return assetCacheRemove(assetKey);
     }
 
     const cacheDict = await getAssetCacheRegistry();
 
-    let entry = cacheDict[assetKey];
-    if ( entry === undefined ) {
-        entry = cacheDict[assetKey] = {};
-    }
+    const { resourceTime, url } = options;
+    const entry = cacheDict[assetKey] || {};
     entry.writeTime = entry.readTime = Date.now();
-    entry.resourceTime = options.resourceTime || 0;
-    if ( typeof options.url === 'string' ) {
-        entry.remoteURL = options.url;
+    entry.resourceTime = resourceTime || 0;
+    if ( typeof url === 'string' ) {
+        entry.remoteURL = url;
     }
-    cacheStorage.set({
-        assetCacheRegistry,
-        [`cache/${assetKey}`]: content
-    });
+    cacheDict[assetKey] = entry;
+
+    await cacheStorage.set({ [`cache/${assetKey}`]: content });
+
+    saveAssetCacheRegistry(3);
 
     const result = { assetKey, content };
     // https://github.com/uBlockOrigin/uBlock-issues/issues/248
@@ -800,21 +776,31 @@ async function assetCacheWrite(assetKey, details) {
     return result;
 }
 
-async function assetCacheRemove(pattern) {
+async function assetCacheRemove(pattern, options = {}) {
     const cacheDict = await getAssetCacheRegistry();
     const removedEntries = [];
     const removedContent = [];
     for ( const assetKey in cacheDict ) {
-        if ( pattern instanceof RegExp && !pattern.test(assetKey) ) {
-            continue;
-        }
-        if ( typeof pattern === 'string' && assetKey !== pattern ) {
-            continue;
+        if ( pattern instanceof RegExp ) {
+            if ( pattern.test(assetKey) === false ) { continue; }
+        } else if ( typeof pattern === 'string' ) {
+            if ( assetKey !== pattern ) { continue; }
         }
         removedEntries.push(assetKey);
-        removedContent.push('cache/' + assetKey);
+        removedContent.push(`cache/${assetKey}`);
         delete cacheDict[assetKey];
     }
+    if ( options.janitor && pattern instanceof RegExp ) {
+        const re = new RegExp(
+            pattern.source.replace(/^\^/, '^cache\\/'),
+            pattern.flags
+        );
+        const keys = await cacheStorage.keys(re);
+        for ( const key of keys ) {
+            removedContent.push(key);
+            ubolog(`Removing stray ${key}`);
+        }
+    }
     if ( removedContent.length !== 0 ) {
         await Promise.all([
             cacheStorage.remove(removedContent),
@@ -854,7 +840,7 @@ async function assetCacheSetDetails(assetKey, details) {
         }
     }
     if ( modified ) {
-        saveAssetCacheRegistry();
+        saveAssetCacheRegistry(3);
     }
 }
 
@@ -980,8 +966,7 @@ assets.get = async function(assetKey, options = {}) {
         }
         if ( details.content === '' ) { continue; }
         if ( reIsExternalPath.test(contentURL) && options.dontCache !== true ) {
-            assetCacheWrite(assetKey, {
-                content: details.content,
+            assetCacheWrite(assetKey, details.content, {
                 url: contentURL,
                 silent: options.silent === true,
             });
@@ -1057,8 +1042,7 @@ async function getRemote(assetKey, options = {}) {
         }
 
         // Success
-        assetCacheWrite(assetKey, {
-            content: result.content,
+        assetCacheWrite(assetKey, result.content, {
             url: contentURL,
             resourceTime: result.resourceTime || 0,
         });
@@ -1101,6 +1085,17 @@ assets.put = async function(assetKey, content) {
 
 /******************************************************************************/
 
+assets.toCache = async function(assetKey, content) {
+    return assetCacheWrite(assetKey, content);
+};
+
+assets.fromCache = async function(assetKey) {
+    const details = await assetCacheRead(assetKey);
+    return details && details.content;
+};
+
+/******************************************************************************/
+
 assets.metadata = async function() {
     await Promise.all([
         getAssetSourceRegistry(),
@@ -1147,8 +1142,8 @@ assets.metadata = async function() {
 
 assets.purge = assetCacheMarkAsDirty;
 
-assets.remove = function(pattern) {
-    return assetCacheRemove(pattern);
+assets.remove = function(...args) {
+    return assetCacheRemove(...args);
 };
 
 assets.rmrf = function() {
@@ -1249,10 +1244,8 @@ async function diffUpdater() {
     ubolog('Diff updater: cycle start');
     return new Promise(resolve => {
         let pendingOps = 0;
-        const bc = new globalThis.BroadcastChannel('diffUpdater');
         const terminate = error => {
             worker.terminate();
-            bc.close();
             resolve();
             if ( typeof error !== 'string' ) { return; }
             ubolog(`Diff updater: terminate because ${error}`);
@@ -1265,14 +1258,15 @@ async function diffUpdater() {
             if ( metadata.diffPath === data.patchPath ) { return; }
             assetCacheSetDetails(data.assetKey, metadata);
         };
-        bc.onmessage = ev => {
+        const worker = new Worker('js/diff-updater.js');
+        worker.onmessage = ev => {
             const data = ev.data || {};
             if ( data.what === 'ready' ) {
                 ubolog('Diff updater: hard updating', toHardUpdate.map(v => v.assetKey).join());
                 while ( toHardUpdate.length !== 0 ) {
                     const assetDetails = toHardUpdate.shift();
                     assetDetails.fetch = true;
-                    bc.postMessage(assetDetails);
+                    worker.postMessage(assetDetails);
                     pendingOps += 1;
                 }
                 return;
@@ -1284,10 +1278,12 @@ async function diffUpdater() {
             if ( data.status === 'needtext' ) {
                 ubolog('Diff updater: need text for', data.assetKey);
                 assetCacheRead(data.assetKey).then(result => {
-                    data.text = result.content;
+                    // https://bugzilla.mozilla.org/show_bug.cgi?id=1929326#c9
+                    //   Must never be set to undefined!
+                    data.text = result.content || '';
                     data.status = undefined;
                     checkAndCorrectDiffPath(data);
-                    bc.postMessage(data);
+                    worker.postMessage(data);
                 });
                 return;
             }
@@ -1300,8 +1296,7 @@ async function diffUpdater() {
                     'Diff-Path',
                     'Diff-Expires',
                 ]);
-                assetCacheWrite(data.assetKey, {
-                    content: data.text,
+                assetCacheWrite(data.assetKey, data.text, {
                     resourceTime: metadata.lastModified || 0,
                 });
                 metadata.diffUpdated = true;
@@ -1324,7 +1319,7 @@ async function diffUpdater() {
             if ( pendingOps === 0 && toSoftUpdate.length !== 0 ) {
                 ubolog('Diff updater: soft updating', toSoftUpdate.map(v => v.assetKey).join());
                 while ( toSoftUpdate.length !== 0 ) {
-                    bc.postMessage(toSoftUpdate.shift());
+                    worker.postMessage(toSoftUpdate.shift());
                     pendingOps += 1;
                 }
             }
@@ -1332,7 +1327,8 @@ async function diffUpdater() {
             ubolog('Diff updater: cycle complete');
             terminate();
         };
-        const worker = new Worker('js/diff-updater.js');
+    }).catch(reason => {
+        ubolog(`Diff updater: ${reason}`);
     });
 }
 
