@@ -19,15 +19,13 @@
     Home: https://github.com/gorhill/uBlock
 */
 
-'use strict';
-
 /******************************************************************************/
 
-import logger from './logger.js';
-import µb from './background.js';
-
 import { MRUCache } from './mrucache.js';
 import { StaticExtFilteringHostnameDB } from './static-ext-filtering-db.js';
+import { entityFromHostname } from './uri-utils.js';
+import logger from './logger.js';
+import µb from './background.js';
 
 /******************************************************************************/
 /******************************************************************************/
@@ -167,8 +165,10 @@ const hashFromStr = (type, s) => {
 //   It's an uncommon case, so it's best to unescape only when needed.
 
 const keyFromSelector = selector => {
+    let matches = reSimplestSelector.exec(selector);
+    if ( matches !== null ) { return matches[0]; }
     let key = '';
-    let matches = rePlainSelector.exec(selector);
+    matches = rePlainSelector.exec(selector);
     if ( matches !== null ) {
         key = matches[0];
     } else {
@@ -176,6 +176,7 @@ const keyFromSelector = selector => {
         if ( matches === null ) { return; }
         key = matches[1] || matches[2];
     }
+    if ( selector.includes(',') ) { return; }
     if ( key.includes('\\') === false ) { return key; }
     matches = rePlainSelectorEscaped.exec(selector);
     if ( matches === null ) { return; }
@@ -198,8 +199,9 @@ const keyFromSelector = selector => {
     }
 };
 
+const reSimplestSelector = /^[#.][\w-]+$/;
 const rePlainSelector = /^[#.][\w\\-]+/;
-const rePlainSelectorEx = /^[^#.\[(]+([#.][\w-]+)|([#.][\w-]+)$/;
+const rePlainSelectorEx = /^[^#.[(]+([#.][\w-]+)|([#.][\w-]+)$/;
 const rePlainSelectorEscaped = /^[#.](?:\\[0-9A-Fa-f]+ |\\.|\w|-)+/;
 const reEscapeSequence = /\\([0-9A-Fa-f]+ |.)/g;
 
@@ -817,9 +819,10 @@ CosmeticFilteringEngine.prototype.retrieveSpecificSelectors = function(
             3
         );
         // Retrieve filters with a entity-based hostname value
-        if ( request.entity !== '' ) {
+        const entity = entityFromHostname(hostname, request.domain);
+        if ( entity !== '' ) {
             this.specificFilters.retrieve(
-                `${hostname.slice(0, -request.domain.length)}${request.entity}`,
+                entity,
                 options.noSpecificCosmeticFiltering ? discardSets : retrieveSets,
                 1
             );
