@@ -435,7 +435,7 @@ onBroadcast(msg => {
                 try {
                     const url = new URL(prefix);
                     if ( url.hostname.length > 0 ) { return url.href; }
-                } catch(_) {
+                } catch {
                 }
             }).filter(prefix => prefix !== undefined);
     }
